@@ -8,6 +8,8 @@ import glob
 from forest import (
         satellite,
         screen,
+        tools,
+        profile,
         series,
         data,
         load,
@@ -232,7 +234,8 @@ def main(argv=None):
         redux.combine_reducers(
             db.reducer,
             layers.reducer,
-            series.reducer,
+            screen.reducer,
+            tools.reducer,
             colors.reducer,
             presets.reducer),
         initial_state=initial_state,
@@ -251,7 +254,7 @@ def main(argv=None):
     layers_ui.connect(store)
 
     # Connect tools controls
-    tools_panel = series.ToolsPanel()
+    tools_panel = tools.ToolsPanel()
     tools_panel.connect(store)
 
     # Connect tap listener
@@ -286,7 +289,10 @@ def main(argv=None):
     connector = layers.ViewerConnector(viewers, old_world).connect(store)
 
     # Set default time series visibility
-    store.dispatch(series.on_toggle())
+    store.dispatch(tools.on_toggle_tool("time_series", False))
+
+    # Set default profile visibility
+    store.dispatch(tools.on_toggle_tool("profile", False))
 
     # Set top-level navigation
     store.dispatch(db.set_value("patterns", config.patterns))
@@ -312,6 +318,7 @@ def main(argv=None):
         bokeh.models.Panel(
             child=bokeh.layouts.column(
                 tools_panel.buttons["toggle_time_series"],
+                tools_panel.buttons["toggle_profile"],
                 ),
             title="Tools"),
         bokeh.models.Panel(
@@ -334,7 +341,16 @@ def main(argv=None):
                 border_fill_alpha=0)
     series_figure.toolbar.logo = None
 
-    tool_layout = series.ToolLayout(series_figure)
+    # Profile sub-figure widget
+    profile_figure = bokeh.plotting.figure(
+                plot_width=300,
+                plot_height=450,
+                toolbar_location=None,
+                border_fill_alpha=0)
+    profile_figure.toolbar.logo = None
+    profile_figure.y_range.flipped = True
+
+    tool_layout = tools.ToolLayout(series_figure, profile_figure)
     tool_layout.connect(store)
 
     series_view = series.SeriesView.from_groups(
@@ -348,6 +364,20 @@ def main(argv=None):
                 .distinct())
     series_args.map(lambda a: series_view.render(*a))
     series_args.map(print)  # Note: map(print) creates None stream
+
+    profile_view = profile.ProfileView.from_groups(
+            profile_figure,
+            config.file_groups)
+    profile_view.add_subscriber(store.dispatch)
+    profile_args = (rx.Stream()
+                .listen_to(store)
+                .map(profile.select_args)
+                .filter(lambda x: x is not None)
+                .distinct())
+    profile_args.map(lambda a: profile_view.render(*a))
+    profile_args.map(print)  # Note: map(print) creates None stream
+
+
     for f in figures:
         f.on_event(bokeh.events.Tap, tap_listener.update_xy)
         marker = screen.MarkDraw(f).connect(store)
